==> qt-creator-1.2.0-src.tar.gz: qt-creator-1.2.0-src/src/plugins/debugger/cdb/cdboptionspage.h <==
/**************************************************************************
**
** This file is part of Qt Creator
**
** Copyright (c) 2009 Nokia Corporation and/or its subsidiary(-ies).
**
** Contact: Nokia Corporation (qt-info@nokia.com)
**
** Commercial Usage
**
** Licensees holding valid Qt Commercial licenses may use this file in
** accordance with the Qt Commercial License Agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Nokia.
**
** GNU Lesser General Public License Usage
**
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** If you are unsure which license is appropriate for your use, please
** contact the sales department at http://www.qtsoftware.com/contact.
**
**************************************************************************/

#ifndef CDBSETTINGSPAGE_H
#define CDBSETTINGSPAGE_H

#include <coreplugin/dialogs/ioptionspage.h>
#include "ui_cdboptionspagewidget.h"

#include <QtGui/QWidget>
#include <QtCore/QPointer>
#include <QtCore/QSharedPointer>

namespace Debugger {
namespace Internal {

struct CdbOptions;

class CdbOptionsPageWidget : public QWidget
{
    Q_OBJECT
public:
    explicit CdbOptionsPageWidget(QWidget *parent);

    void setOptions(CdbOptions &o);
    CdbOptions options() const;

    void setFailureMessage(const QString &);

private slots:
    void autoDetect();
    void downLoadLinkActivated(const QString &);

private:
    Ui::CdbOptionsPageWidget m_ui;
};

class CdbOptionsPage : public Core::IOptionsPage
{
    Q_DISABLE_COPY(CdbOptionsPage)
    Q_OBJECT
public:
    explicit CdbOptionsPage(const QSharedPointer<CdbOptions> &options);
    virtual ~CdbOptionsPage();

    // IOptionsPage
    virtual QString id() const { return settingsId(); }
    virtual QString trName() const;
    virtual QString category() const;
    virtual QString trCategory() const;

    virtual QWidget *createPage(QWidget *parent);
    virtual void apply();
    virtual void finish();

    static QString settingsId();

    // Load  failure messages can be displayed here
    void setFailureMessage(const QString &msg) { m_failureMessage = msg; }

signals:
    void debuggerPathsChanged();

private:
    const QSharedPointer<CdbOptions> m_options;
    QPointer<CdbOptionsPageWidget> m_widget;
    QString m_failureMessage;
};

} // namespace Internal
} // namespace Debugger

#endif // CDBSETTINGSPAGE_H

==> qt-creator-2.1.0-src.tar.gz: qt-creator-2.1.0-src/src/plugins/debugger/cdb/cdboptionspage.h <==
/**************************************************************************
**
** This file is part of Qt Creator
**
** Copyright (c) 2011 Nokia Corporation and/or its subsidiary(-ies).
**
** Contact: Nokia Corporation (qt-info@nokia.com)
**
** No Commercial Usage
**
** This file contains pre-release code and may not be distributed.
** You may use this file in accordance with the terms and conditions
** contained in the Technology Preview License Agreement accompanying
** this package.
**
** GNU Lesser General Public License Usage
**
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Nokia gives you certain additional
** rights.  These rights are described in the Nokia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** If you have questions regarding the use of this file, please contact
** Nokia at qt-info@nokia.com.
**
**************************************************************************/

#ifndef CDBSETTINGSPAGE_H
#define CDBSETTINGSPAGE_H

#include "cdboptions.h"

#include <coreplugin/dialogs/ioptionspage.h>
#include "ui_cdboptionspagewidget.h"

#include <QtGui/QWidget>
#include <QtCore/QPointer>
#include <QtCore/QSharedPointer>

namespace Debugger {
namespace Internal {

class CdbOptionsPageWidget : public QWidget
{
    Q_OBJECT
public:
    explicit CdbOptionsPageWidget(QWidget *parent);

    void setOptions(CdbOptions &o);
    CdbOptions options() const;

    void setFailureMessage(const QString &);

    QString searchKeywords() const;

private slots:
    void autoDetect();
    void downLoadLinkActivated(const QString &);

private:
    Ui::CdbOptionsPageWidget m_ui;
};

class CdbOptionsPage : public Core::IOptionsPage
{
    Q_DISABLE_COPY(CdbOptionsPage)
    Q_OBJECT
public:
    explicit CdbOptionsPage();
    virtual ~CdbOptionsPage();

    // IOptionsPage
    virtual QString id() const { return settingsId(); }
    virtual QString displayName() const;
    virtual QString category() const;
    virtual QString displayCategory() const;
    QIcon categoryIcon() const;

    virtual QWidget *createPage(QWidget *parent);
    virtual void apply();
    virtual void finish();
    virtual bool matches(const QString &) const;

    static QString settingsId();

    // Load  failure messages can be displayed here
    void setFailureMessage(const QString &msg) { m_failureMessage = msg; }
    QSharedPointer<CdbOptions> options() const { return m_options; }

signals:
    void debuggerPathsChanged();
    void optionsChanged();

private:
    const QSharedPointer<CdbOptions> m_options;
    QPointer<CdbOptionsPageWidget> m_widget;
    QString m_failureMessage;
    QString m_searchKeywords;
};

} // namespace Internal
} // namespace Debugger

#endif // CDBSETTINGSPAGE_H
